@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public
  * License along with this library; see the file COPYING.
  * If not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <qdatetime.h>
 #include <qfile.h>
@@ -35,16 +35,15 @@ typedef KGenericFactory<KTorrentPlugin> TorrentFactory;
 K_EXPORT_COMPONENT_FACTORY(kfile_torrent, TorrentFactory("kfile_torrent"))
 
 QStringList filesList (BList *list);
-Q_ULLONG filesLength (BList *list);
+qulonglong filesLength (BList *list);
 
-KTorrentPlugin::KTorrentPlugin (QObject *parent, const char *name,
-                                const QStringList &args)
-    : KFilePlugin (parent, name, args), m_failed(true), m_dict(0)
+KTorrentPlugin::KTorrentPlugin (QObject *parent, const QStringList &args)
+    : KFilePlugin (parent, args), m_failed(true), m_dict(0)
 {
     KFileMimeTypeInfo *info = addMimeTypeInfo ("application/x-bittorrent");
     if (!info)
     {
-        kdError() << "Error creating application/x-bittorrent mime type info!\n";
+        kError() << "Error creating application/x-bittorrent mime type info!\n";
         return;
     }
 
@@ -52,7 +51,7 @@ KTorrentPlugin::KTorrentPlugin (QObject *parent, const char *name,
         addGroupInfo (info, "TorrentInfo", i18n("Torrent Information"));
     if (!group)
     {
-        kdError() << "Error creating TorrentInfo group!\n";
+        kError() << "Error creating TorrentInfo group!\n";
         return;
     }
     setAttributes (group, KFileMimeTypeInfo::Modifiable);
@@ -62,7 +61,7 @@ KTorrentPlugin::KTorrentPlugin (QObject *parent, const char *name,
     item = addItemInfo(group, "name", i18n("Name"), QVariant::String);
     if (!item)
     {
-        kdError() << "Error adding Name to group!\n";
+        kError() << "Error adding Name to group!\n";
         return;
     }
     setHint (item, KFileMimeTypeInfo::Name);
@@ -71,7 +70,7 @@ KTorrentPlugin::KTorrentPlugin (QObject *parent, const char *name,
     item = addItemInfo(group, "length", i18n("Torrent Length"), QVariant::ULongLong);
     if (!item)
     {
-        kdError() << "Error adding Length to group!\n";
+        kError() << "Error adding Length to group!\n";
         return;
     }
     setHint (item, KFileMimeTypeInfo::Length);
@@ -80,28 +79,28 @@ KTorrentPlugin::KTorrentPlugin (QObject *parent, const char *name,
     item = addItemInfo(group, "announce", i18n("Tracker URL"), QVariant::String);
     if (!item)
     {
-        kdError() << "Error adding Announce to group!\n";
+        kError() << "Error adding Announce to group!\n";
         return;
     }
     
     item = addItemInfo(group, "creation date", i18n("Date Created"), QVariant::DateTime);
     if (!item)
     {
-        kdError() << "Error adding DateCreated to group!\n";
+        kError() << "Error adding DateCreated to group!\n";
         return;
     }
     
     item = addItemInfo(group, "NumFiles", i18n("Number of Files"), QVariant::Int);
     if (!item)
     {
-        kdError() << "Error adding NumFiles to group!\n";
+        kError() << "Error adding NumFiles to group!\n";
         return;
     }
     
     item = addItemInfo(group, "piece length", i18n("File Piece Length"), QVariant::Int);
     if (!item)
     {
-        kdError() << "Error adding PieceLength to group!\n";
+        kError() << "Error adding PieceLength to group!\n";
         return;
     }
     setUnit (item, KFileMimeTypeInfo::Bytes);
@@ -109,7 +108,7 @@ KTorrentPlugin::KTorrentPlugin (QObject *parent, const char *name,
     item = addItemInfo(group, "comment", i18n("Comment"), QVariant::String);
     if (!item)
     {
-        kdError() << "Error adding Comment to group!\n";
+        kError() << "Error adding Comment to group!\n";
         return;
     }
     setAttributes (item, KFileMimeTypeInfo::MultiLine | KFileMimeTypeInfo::Modifiable);
@@ -124,15 +123,15 @@ bool KTorrentPlugin::readInfo (KFileMetaInfo &info, unsigned int)
      */
     if (m_failed)
     {
-        kdError() << "Construction of KTorrentPlugin failed for " << info.path() << endl;
-        kdError() << "Aborting meta-info read.\n";
+        kError() << "Construction of KTorrentPlugin failed for " << info.path() << endl;
+        kError() << "Aborting meta-info read.\n";
         return false;
     }
     
     QFile file (info.path());
-    if (!file.open(IO_ReadOnly))
+    if (!file.open(QIODevice::ReadOnly))
     {
-        kdError() << "Unable to open given file!\n";
+        kError() << "Unable to open given file!\n";
         return false;
     }
 
@@ -140,9 +139,9 @@ bool KTorrentPlugin::readInfo (KFileMetaInfo &info, unsigned int)
     QByteArray buf = file.readAll();
     file.close();
 
-    if (!buf)
+    if (!buf.isEmpty())
     {
-        kdError() << "Empty file: " << info.path() << endl;
+        kError() << "Empty file: " << info.path() << endl;
         return false;
     }
 
@@ -150,13 +149,13 @@ bool KTorrentPlugin::readInfo (KFileMetaInfo &info, unsigned int)
     
     if (!m_dict)
     {
-        kdError() << "Error creating dictionary from open file: " << info.path() << endl;
+        kError() << "Error creating dictionary from open file: " << info.path() << endl;
         return false;
     }
 
     if (!m_dict->isValid())
     {
-        kdDebug(7034) << "Invalid torrent file: " << info.path() << endl;
+        kDebug(7034) << "Invalid torrent file: " << info.path();
         return false;
     }
     
@@ -193,7 +192,7 @@ bool KTorrentPlugin::readInfo (KFileMetaInfo &info, unsigned int)
     // it.
     BDict *info_dict = m_dict->findDict("info");
     int num_files = 1;
-    Q_ULLONG length = 0;
+    qulonglong length = 0;
     
     if (!info_dict)
         return false;
@@ -315,9 +314,9 @@ QStringList filesList (BList *list)
 /* This function determines the total length of a torrent stream.
  * The list provided should be the same one provided for filesList.
  */
-Q_ULLONG filesLength (BList *list)
+qulonglong filesLength (BList *list)
 {
-    Q_ULLONG length = 0;
+    qulonglong length = 0;
 
     for (unsigned int i = 0; i < list->count(); ++i)
     {
@@ -393,7 +392,7 @@ bool KTorrentPlugin::writeInfo(const KFileMetaInfo &info) const
         
     QFile output (info.path());
     
-    if (!output.open(IO_WriteOnly | IO_Truncate))
+    if (!output.open(QIODevice::WriteOnly | QIODevice::Truncate))
         return false;
     
     return m_dict->writeToDevice(output);
